@@ -36,12 +36,10 @@
     </p>
 
 <?php if (0 !== $maxActiveConfigurations): ?>
+    <h2><?= $this->t('Manual Configuration'); ?></h2>
     <p>
         <?= $this->t('If you do not want to, or cannot use the official Let\'s Connect! apps, you can also manually obtain a VPN configuration and import it in your existing VPN application.'); ?>
     </p>
-    <details>
-        <summary><?= $this->t('Manual Configuration'); ?></summary>
 <?= $this->insert('manualConfiguration'); ?>
-    </details>
 <?php endif; ?>
 <?php $this->stop('content'); ?>
